@@ -97,7 +97,7 @@ HatchingSuccess.MHmcmc <- function(result=stop("Give a result of HatchingSuccess
   
   fin <- try(summary(out), silent=TRUE)
   
-  if (class(fin)=="try-error") {
+  if (inherits(fin, "try-error")) { #(class(fin)=="try-error") {
     lp <- rep(NA, nrow(out$parametersMCMC$parameters))
     names(lp) <- rownames(out$parametersMCMC$parameters)
     out <- c(out, TimeSeriesSE=list(lp))
